Class: Foursquare::User
Class Method Summary collapse
-
.find(options = {}) ⇒ Object
Returns data for a particular user.
Methods inherited from Base
authentication, connect, latitude, location, location=, longitude
Class Method Details
.find(options = {}) ⇒ Object
Returns data for a particular user
Options :uid => userid for the user whose information you want to retrieve. if you do not specify a 'uid', the authenticated user's profile data will be returned. :badges => (optional, default: false) set to true ("1") to also show badges for this user :mayor => (optional, default: false) set to true ("1") to also show venues for which this user is a mayor
13 14 15 |
# File 'lib/foursquare/user.rb', line 13 def self.find( = {}) get("/user.json", :query => )["user"] end |